Learn R Programming

clarkeTest (version 0.1.0)

indivLogLiks: Calculate individual log-likelihood values

Description

Calculate individual log-likelihood values

Usage

indivLogLiks(model)

# S3 method for glm indivLogLiks(model)

# S3 method for lm indivLogLiks(model)

# S3 method for polr indivLogLiks(model)

# S3 method for clm indivLogLiks(model)

# S3 method for multinom indivLogLiks(model)

# S3 method for negbin indivLogLiks(model)

Arguments

model

A statistical model object.

Value

A vector of individual log-likelihood values for the model.

Details

The indivLogLiks function calls the appropriate method for calculating individual log likelihood values for the model. The function currently supports binomial, poisson and negative binomial GLMs, ordinal models estimated with either polr from the MASS package or clm from the ordinal package and multinomial models estimated with either multinom from the nnet package. Users can also write new methods for both indivLogLiks and nparams that would get called by the generic function.

For the purposes of the clarke_test function, the indivLogLiks functions are not intended to be called directly by the user.